==> faas-0.0.24.tgz: package/api.js <==
var utils = require('./utils')
  , logger = require('./logger')
  , request = require('request')
  , http = require('http')
  , url = require('url')
var pkgjson = require('./package.json')

var API_CONFIG = {
  allowUnverified: false
  , key: process.env.FAAS_API_KEY
  , secret: process.env.FAAS_API_SECRET
  , hostname: 'api-beta.faas.io'
}

var debug = logger('api') // Local logger.

exports.config = function(config){
  if (config) {
    var apiConf = {}
    if (config.apiKey) { apiConf.key = config.apiKey }
    if (config.apiSecret) { apiConf.secret = config.apiSecret }
    apiConfig(apiConf)
  }
}


exports.apiConfig = apiConfig = function(config){
  utils.extend(API_CONFIG, config)
  return utils.shallowCopy(API_CONFIG)
}


////
// Interface for performing API calls.
////
exports.api = function(options, callback){
  debug('options', options)
  callback = debug.wrap(callback)

  var urlOpts = options.url
  // Default the credentials.
  var query = { apiKey: API_CONFIG.key, apiSecret: API_CONFIG.secret }
  if (urlOpts.query) {
    utils.extend(query, urlOpts.query)
  }
  query.npmVer = pkgjson.version
  urlOpts.query = query
  urlOpts.hostname = API_CONFIG.hostname
  urlOpts.protocol = 'https:'

  // Be clear about configuration errors.
  var cfgErrors = []
  if (!urlOpts.hostname) {
    cfgErrors.push('blank api hostname')
  }
  if (!urlOpts.query.apiKey) {
    cfgErrors.push('missing api key')
  }
  if (!urlOpts.query.apiSecret) {
    cfgErrors.push('missing api secret')
  }
  if (cfgErrors.length > 0) {
    debug('ERROR urlOpts', urlOpts)
    callback('Invalid configuration options: '+cfgErrors.join('; '))
    return
  }

  var reqOpts = {
    uri: url.format(urlOpts)
    , method: options.method || 'GET'
    , json: options.data || true
    , encoding: 'utf8'
    , strictSSL: API_CONFIG.allowUnverified ? false : true // Disable SSL certificate checking.
  }

  debug('reqOpts', reqOpts)

  request(reqOpts, function(err, res, body){
    debug('response', res && res.statusCode, res && res.headers, body)
    if (!err && res && (res.statusCode < 200 || res.statusCode >= 300)) {
      err = body && body.error || (res.statusCode+": "+http.STATUS_CODES[res.statusCode])+': '+JSON.stringify(body)
    }
    if (body && body.data) {
      body = body.data
    }
    callback(err, body)
  })
}

==> faas-0.0.33.tgz: package/api.js <==
var utils = require('./utils')
  , logger = require('./logger')
  , request = require('request')
  , http = require('http')
  , url = require('url')
var pkgjson = require('./package.json')

var API_CONFIG = {
  allowUnverified: false
  , key: process.env.FAAS_API_KEY
  , secret: process.env.FAAS_API_SECRET
  , hostname: 'api.faas.io'
}

var debug = logger('api') // Local logger.

exports.config = function(config){
  if (config) {
    var apiConf = {}
    if (config.apiKey) { apiConf.key = config.apiKey }
    if (config.apiSecret) { apiConf.secret = config.apiSecret }
    apiConfig(apiConf)
  }
}


exports.apiConfig = apiConfig = function(config){
  utils.extend(API_CONFIG, config)
  return utils.shallowCopy(API_CONFIG)
}


////
// Interface for performing API calls.
////
exports.api = function(options, callback){
  debug('options', options)
  callback = debug.wrap(callback)

  var urlOpts = options.url
  // Default the credentials.
  var query = { apiKey: API_CONFIG.key, apiSecret: API_CONFIG.secret }
  if (urlOpts.query) {
    utils.extend(query, urlOpts.query)
  }
  query.npmVer = pkgjson.version
  urlOpts.query = query
  urlOpts.hostname = API_CONFIG.hostname
  urlOpts.protocol = 'https:'

  // Be clear about configuration errors.
  var cfgErrors = []
  if (!urlOpts.hostname) {
    cfgErrors.push('blank api hostname')
  }
  if (!urlOpts.query.apiKey) {
    cfgErrors.push('missing api key')
  }
  if (!urlOpts.query.apiSecret) {
    cfgErrors.push('missing api secret')
  }
  if (cfgErrors.length > 0) {
    debug('ERROR urlOpts', urlOpts)
    callback('Invalid configuration options: '+cfgErrors.join('; '))
    return
  }

  var reqOpts = {
    uri: url.format(urlOpts)
    , method: options.method || 'GET'
    , json: options.data || true
    , encoding: 'utf8'
    , strictSSL: API_CONFIG.allowUnverified ? false : true // Disable SSL certificate checking.
  }

  debug('reqOpts', reqOpts)

  request(reqOpts, function(err, res, body){
    debug('response', res && res.statusCode, res && res.headers, body)
    if (!err && res && (res.statusCode < 200 || res.statusCode >= 300)) {
      err = body && body.error || (res.statusCode+": "+http.STATUS_CODES[res.statusCode])+': '+JSON.stringify(body)
    }
    if (body && body.data) {
      body = body.data
    }
    callback(err, body)
  })
}
